# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-10-31 01:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lp_accounts', '0002_user_is_confirmed'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='type',
            field=models.IntegerField(choices=[(1, 'Default'), (2, 'Google'), (3, 'Facebook'), (4, 'Github'), (5, 'LinkedIn')], default=1),
        ),
    ]
